@@ -40,20 +40,20 @@ class Chart:
         df = DataFrame(columns=data['data']['columns'], data=data['data']['data'])
         return cls(chart_type=data['chart_type'], data=df, data_fields=data['data_fields'], label_fields=data['label_fields'])
 
-    def to_dict(self):
+    def to_dict(self, key_name:str):
         return {
             "data": self.data.to_dict(),
             "log_type": self.log_type,
             "chart_type": self.chart_type,
             "data_fields": self.data_fields,
             "label_fields": self.label_fields,
+            "path": self.get_path(key_name),
         }
 
     def to_json(self, key_name: str) -> str:
         assert_that(key_name).is_not_none()
-
-
         return json.dumps({
+            "data": self.data.to_dict(),
             "log_type": self.log_type,
             "chart_type": self.chart_type,
             "data_fields": self.data_fields,
@@ -77,11 +77,11 @@ class Chart:
                               entry_list=[], file_index=0)
 
 
-    def file_dump(self, path: str) -> Tuple[str, str]:
+    def file_dump(self, path: str, key_name: str) -> Tuple[str, str]:
         Path(os.path.dirname(path)).mkdir(parents=True, exist_ok=True)
 
         with open(path, "w") as f:
-            json.dump(self.to_dict(), f)
+            json.dump(self.to_dict(key_name), f)
 
         with open(path, "rb") as f:
             digest = hashlib.md5(f.read()).hexdigest()
