@@ -3,7 +3,8 @@ import json
 import os
 import random
 import string
-from typing import Union, Dict
+from pathlib import Path
+from typing import Union, Dict, Tuple
 
 from PIL import Image as PIL_IMAGE
 from assertpy import assert_that
@@ -43,8 +44,8 @@ class Image(Media):
             raise Exception(f"unknown data type {type(data)}")
 
         # caption, boxes 처리
-        self.caption :str = caption
-        self.boxes :Dict = None
+        self.caption: str = caption
+        self.boxes: Dict = None
 
         if boxes:
             if isinstance(boxes, BoundingBoxes):
@@ -56,8 +57,6 @@ class Image(Media):
                     class_labels=list(boxes.values())[0]['class_labels'])
                 self.boxes = bb
 
-
-
     def to_json(self, key_name: str, is_list=False, index=0) -> str:
         assert_that(key_name).is_not_none()
 
@@ -105,5 +104,24 @@ class Image(Media):
             # server 패스
             return f"{key_name}.IMAGE.{self.format}"
 
+    def get_path_json(self, key_name: str, is_list=False, index=0) -> str:
+        if is_list:
+            return f"{key_name}.IMAGE.{index}.json"
+        else:
+            # server 패스
+            return f"{key_name}.IMAGE.json"
+
     def get_root_path(self, run_id: int) -> str:
         return os.path.join(str(run_id), "media")
+
+    def file_dump(self, path: str, key_name: str, is_list=False, index=0) -> Tuple[str, str]:
+        Path(os.path.dirname(path)).mkdir(parents=True, exist_ok=True)
+
+        with open(path, "w") as f:
+            json.dump(self.to_dict(key_name, is_list, index), f)
+
+        with open(path, "rb") as f:
+            digest = hashlib.md5(f.read()).hexdigest()
+            f.seek(0, os.SEEK_END)
+            size = f.tell()
+        return digest, size
