@@ -38,23 +38,26 @@ class Table(Media):
         # return "1"
         return self.data.dataframe._repr_html_()
 
-    def to_dict(self):
+    def to_dict(self, key_name):
         return {
             "data": self.data.to_dict(),
+            "log_type": self.log_type,
+            "path": self.get_path(key_name),
+            "cols": len(self.data.dataframe.columns),
+            "rows": len(self.data.dataframe),
         }
 
     def to_json(self, key_name: str) -> str:
         assert_that(key_name).is_not_none()
 
         return json.dumps({
+            "data": self.data.to_dict(),
             "log_type": self.log_type,
             "path": self.get_path(key_name),
             "cols": len(self.data.dataframe.columns),
             "rows": len(self.data.dataframe),
         })
 
-
-
     # 실제 파일 서버로 전송
     # Run.log에 Image 객체가 기록된 경우 Image 의 값을 올리기 위한 함수
     # table내용을 json으로 변환하여 파일로 저장후 전송
@@ -73,11 +76,11 @@ class Table(Media):
                               expName=run.exp_name, run_name=run.run_name, artifact_name="", artifact_type="",
                               artifact_digest="", entry_digest=digest, entry_list=[], file_index=0)
 
-    def file_dump(self, path: str) -> Tuple[str, str]:
+    def file_dump(self, path: str, key_name: str) -> Tuple[str, str]:
         Path(os.path.dirname(path)).mkdir(parents=True, exist_ok=True)
 
         with open(path, "w") as f:
-            json.dump(self.to_dict(), f)
+            json.dump(self.to_dict(key_name), f)
 
         with open(path, "rb") as f:
             digest = hashlib.md5(f.read()).hexdigest()
