@@ -200,7 +200,7 @@ def prepare_code(code: dict = None) -> Tuple[bool, str, Callable]:
 @util.login_required
 def get_hpo(exp_name: str = "", team_name: str = "") -> (bool, Dict, str):
 
-    rsp = interface.get_hpo(exp_name, team_name_)
+    rsp = interface.get_hpo(exp_name, team_name)
 
     if rsp['result'] == "success":
         return True, rsp['hpoConfig'], rsp['teamName']
